@@ -1,16 +1,17 @@
-package Dist::Zilla::PluginBundle::GEEKRUTH 1.0001;
+package Dist::Zilla::PluginBundle::GEEKRUTH;
 use Modern::Perl;
+our $VERSION   = '2.0000';           # VERSION
+our $AUTHORITY = 'cpan:GEEKRUTH';    # AUTHORITY
 
 # ABSTRACT: Be like GeekRuthie when you build your dists
 
 use Moose;
 use Dist::Zilla;
-
 with qw/
    Dist::Zilla::Role::PluginBundle::Easy
    Dist::Zilla::Role::PluginBundle::Config::Slicer
+   Dist::Zilla::Role::PluginBundle::PluginRemover
    /;
-
 use Type::Tiny;
 use Types::Standard qw/ Str ArrayRef /;
 
@@ -71,17 +72,22 @@ sub configure {
       ],
       qw/
          MetaProvides::Package
+         MetaData::BuiltWith
          Manifest
          ManifestSkip
          Git::GatherDir
-         CopyFilesFromBuild
-         ExecDir
          /,
-      [ PkgVersion => { use_package => 1 } ],
+      [ CopyFilesFromBuild => { copy => 'cpanfile' } ],
+      qw/
+         PruneCruft
+         ExecDir
+         OurPkgVersion
+         INI::Baked
+         /,
       [
          Authority => {
-            authority  => $arg->{authority} // 'cpan:GEEKRUTH',
-            do_munging => 0,
+            authority      => $arg->{authority} // 'cpan:GEEKRUTH',
+            locate_comment => 1,
          }
       ],
       qw/ Test::ReportPrereqs /,
@@ -90,14 +96,14 @@ sub configure {
             ( skip => $arg->{autoprereqs_skip} ) x !!$arg->{autoprereqs_skip}
          }
       ],
-      qw/ CheckChangesHasContent
+      qw/ Prereqs::Plugins
+         CheckChangesHasContent
          ReadmeMarkdownFromPod
          TestRelease
          ConfirmRelease
          Git::Check
          CopyrightYearFromGit
          /,
-
       [
          'Git::CommitBuild' => {
             release_branch       => $release_branch,
@@ -119,6 +125,7 @@ sub configure {
             major    => 'MAJOR, API CHANGES',
             minor    => 'MINOR, NEW FEATURES, ENHANCEMENTS',
             revision => 'REVISION, BUG FIXES, DOCUMENTATION, STATISTICS',
+            format   => '%d.%02d%02d',
          }
       ],
       [
@@ -149,7 +156,6 @@ sub configure {
    $self->add_plugins(
       qw/
          SchwartzRatio
-         Test::UnusedVars
          RunExtraTests
          /,
    );
@@ -162,7 +168,10 @@ sub configure {
       );
    }
 
-   $self->add_plugins( [ 'CPANFile', 'MinimumPerlFast' ], );
+   $self->add_plugins(
+      qw/CPANFile/,
+      [ 'MinimumPerl' => { default_version => '5.012' } ],
+   );
 
    $self->config_slice('mb_class');
 
@@ -183,7 +192,7 @@ Dist::Zilla::PluginBundle::GEEKRUTH - Be like GeekRuthie when you build your dis
 
 =head1 VERSION
 
-version 1.0001
+version 2.0000
 
 =head1 DESCRIPTION
 
@@ -211,20 +220,22 @@ her distributions. It's roughly equivalent to
    time_zone = America/New_York
    
    [MetaProvides::Package]
+   [MetaData::BuiltWith]
    [Manifest]
    [ManifestSkip]
    [Git::GatherDir]
+   [PruneCruft]
    [CopyFilesFromBuild]
+   copy = cpanfile
    [ExecDir]
-   [PkgVersion]
-   use_package = 1
-   
+   [OurPkgVersion]
+   [INI::Baked]
    [Authority]
-   do_munging = 0
-   
+   locate_comment =    
    [Test::ReportPrereqs]
    [TidyAll]
    [AutoPrereqs]
+   [Prereqs::Plugins]
    [CheckChangesHasContent]
    [ReadmeMarkdownFromPod]
    [TestRelease]
@@ -263,7 +274,7 @@ her distributions. It's roughly equivalent to
    [RunExtraTests]
    [Test::UnusedVars]
    [CPANFile]
-   [MinimumPerlFast]
+   [MinimumPerl]
 
 =head1 ARGUMENTS
 
@@ -309,6 +320,10 @@ Branch on which the CPAN images are commited.
 
 Defaults to C<releases>.
 
+=item C<remove_plugin>
+
+Lets you drop a plugin from the bundle for this distro; see L<Dist::Zilla::Role::PluginBundle::PluginRemover>.
+
 =item C<upstream>
 
 The name of the upstream repo. 
